Contributors
============

This list includes people who have contributed to the project in the form of code,
comments, testing, bug reports, or feature requests.

* `Morgan Williams <https://github.com/morganjwilliams>`__
* Hayden Dalton
* `Louise Schoneveld <https://github.com/lavender22>`__
* Adam Bath
* Yajing Mao
* `Justin Gosses <https://github.com/JustinGOSSES>`__
* `Kaarel Mand <https://github.com/kaarelmand>`__
* `Laura Miller <https://github.com/Lauraanme>`__
* Steve Barnes
* Lucy Mathieson
* `Nicolas Piette-Lauziere <https://github.com/NicolasPietteLauziere>`__
* `Chetan Nathwani <https://github.com/ChetanNathwani>`__
* `Martin Bentley <https://github.com/mtb-za>`__
* `Tom Buckle <https://github.com/bomtuckle>`__
* `Angela Rodrigues <https://github.com/AngRodrigues>`__
* `Sarah Shi <https://github.com/sarahshi>`__
* `Ondrej Lexa <https://github.com/ondrolexa>`__
